@@ -20,3 +20,11 @@ class NoSuchSourceException(BaseException):
 
 class VirtualenvFailException(BaseException):
     pass
+
+
+class ExtractionError(BaseException):
+    pass
+
+
+class MissingUrlException(BaseException):
+    pass
